==> nomad_media_pip-0.0.119-py3-none-any.whl: nomad_media_pip/src/admin/schedule/create_intelligent_playlist.py <==
from nomad_media_pip.src.exceptions.api_exception_handler import _api_exception_handler
from nomad_media_pip.src.admin.schedule.delete_intelligent_playlist import _delete_intelligent_playlist

import requests, json, time

MAX_RETRIES = 2

def _create_intelligent_playlist(self, AUTH_TOKEN, URL, COLLECTIONS, END_SEARCH_DATE, 
                                 END_SEARCH_DURATION_IN_MINUTES, NAME, RELATED_CONTENT, 
                                 SEARCH_DATE, SEARCH_DURATION_IN_MINUTES, SEARCH_FILTER_TYPE, 
                                 TAGS, THUMBNAIL_ASSET, DEBUG):
    
    SCHEDULE_API_URL = f"{URL}/api/admin/schedule"

    
    HEADERS = {
        "Authorization": "Bearer " + AUTH_TOKEN,
        "Content-Type": "application/json"
    }

    SCHEUDLE_BODY = {
        "name": NAME,
        "scheduleType": "4",
        "thumbnailAsset": THUMBNAIL_ASSET
    }

    if DEBUG:
        print(f"URL: {SCHEDULE_API_URL},\nMETHOD: POST,\nBODY: {json.dumps(SCHEUDLE_BODY)}")

    retries = 0
    while True:
        try:
            SCHEDULE_RESPONSE = requests.post(SCHEDULE_API_URL, headers= HEADERS, data= json.dumps(SCHEUDLE_BODY))

            if SCHEDULE_RESPONSE.ok:
                break

            if SCHEDULE_RESPONSE.status_code == 403:
                self.refresh_token()
            else:
                raise Exception()
            
        except requests.exceptions.Timeout:
            if retries < MAX_RETRIES:
                retries += 1
                time.sleep(20)
            else:
                _api_exception_handler(SCHEDULE_RESPONSE, "Create Intelligent Playlist Failed")

        except:
            _api_exception_handler(SCHEDULE_RESPONSE, "Create Intelligent Playlist Failed")

    SCHEDULE_INFO = SCHEDULE_RESPONSE.json()

    ITEM_API_URL = f"{SCHEDULE_API_URL}/{SCHEDULE_INFO['id']}/item"

    ITEM_BODY = {
        "collections": COLLECTIONS,
        "endSearchDate": END_SEARCH_DATE,
        "endSearchDurationInMinutes": END_SEARCH_DURATION_IN_MINUTES,
        "name": NAME,
        "relatedContent": RELATED_CONTENT,
        "searchDate": SEARCH_DATE,
        "searchDurationInMinutes": SEARCH_DURATION_IN_MINUTES,
        "searchFilterType": SEARCH_FILTER_TYPE,
        "tags": TAGS,
        "thumbnailAsset": THUMBNAIL_ASSET
    }

    if DEBUG:
        print(f"URL: {ITEM_API_URL},\nMETHOD: POST,\nBODY: {json.dumps(ITEM_BODY)}")

    retries = 0
    while True:
        try:
            RESPONSE = requests.post(ITEM_API_URL, headers= HEADERS, data= json.dumps(ITEM_BODY))

            if RESPONSE.ok:
                ITEM_INFO = RESPONSE.json()

                for param in SCHEDULE_INFO:
                    ITEM_INFO[param] = SCHEDULE_INFO[param]

                break

            if RESPONSE.status_code == 403:
                self.refresh_token()
            else:
                raise Exception()
            
        except requests.exceptions.Timeout:
            if retries < MAX_RETRIES:
                retries += 1
                time.sleep(20)
            else:
                _delete_intelligent_playlist(self, AUTH_TOKEN, URL, SCHEDULE_INFO["id"], DEBUG)
                _api_exception_handler(RESPONSE, "Create Intelligent Playlist Failed")
            
        except:
            _delete_intelligent_playlist(self, AUTH_TOKEN, URL, SCHEDULE_INFO["id"], DEBUG)
            _api_exception_handler(RESPONSE, "Create Intelligent Playlist Failed")
        
    return ITEM_INFO

==> nomad_media_pip-0.0.126-py3-none-any.whl: nomad_media_pip/src/admin/schedule/create_intelligent_playlist.py <==
from nomad_media_pip.src.helpers.send_request import _send_request
from nomad_media_pip.src.admin.schedule.delete_intelligent_playlist import _delete_intelligent_playlist

def _create_intelligent_playlist(self, AUTH_TOKEN, URL, COLLECTIONS, END_SEARCH_DATE, 
                                 END_SEARCH_DURATION_IN_MINUTES, NAME, RELATED_CONTENT, 
                                 SEARCH_DATE, SEARCH_DURATION_IN_MINUTES, SEARCH_FILTER_TYPE, 
                                 TAGS, THUMBNAIL_ASSET, DEBUG):
    
    SCHEDULE_API_URL = f"{URL}/api/admin/schedule"

    SCHEUDLE_BODY = {
        "name": NAME,
        "scheduleType": "4",
        "thumbnailAsset": THUMBNAIL_ASSET
    }

    SCHEDULE_INFO = _send_request(self, AUTH_TOKEN, "Creating Intelligent Playlist", SCHEDULE_API_URL, "POST", None, SCHEUDLE_BODY, DEBUG)

    ITEM_API_URL = f"{SCHEDULE_API_URL}/{SCHEDULE_INFO['id']}/item"

    ITEM_BODY = {
        "collections": COLLECTIONS,
        "endSearchDate": END_SEARCH_DATE,
        "endSearchDurationInMinutes": END_SEARCH_DURATION_IN_MINUTES,
        "name": NAME,
        "relatedContent": RELATED_CONTENT,
        "searchDate": SEARCH_DATE,
        "searchDurationInMinutes": SEARCH_DURATION_IN_MINUTES,
        "searchFilterType": SEARCH_FILTER_TYPE,
        "tags": TAGS,
        "thumbnailAsset": THUMBNAIL_ASSET
    }

    ITEM_INFO = _send_request(self, AUTH_TOKEN, "Creating Intelligent Playlist", ITEM_API_URL, "POST", None, ITEM_BODY, DEBUG)

    for param in SCHEDULE_INFO:
        ITEM_INFO[param] = SCHEDULE_INFO[param]
        
    return ITEM_INFO
